remove — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# remove

poscar_modify.remove(atoms: List[int] | np.ndarray, human: bool = False)

  Removes a list of atoms from the Poscar object. The order of removal is not trivial, and it is equivalent to removing all the desired atoms at once.

  Parameters:

    - atoms (List[int] | np.ndarray) – a list with the indexes of the atoms to remove

    - human (bool) – does atoms start from 1 (True) or 0 (False)? Default is False